@@ -37,16 +37,16 @@ HANDSHAKE = ('\n'.join([STREAM_PROTOCOL, TACVIEW_PROTOCOL, CLIENT, PASSWORD]) +
 
 COORD_KEYS = ('lon', 'lat', 'alt', 'roll', 'pitch', 'yaw', 'u_coord',
               'v_coord', 'heading')
-COORD_KEY_LEN = len(COORD_KEYS)-1
+COORD_KEY_LEN = len(COORD_KEYS)
 
 COORD_KEYS_SHORT = ('lon', 'lat', 'alt', 'u_coord', 'v_coord')
-COORD_KEY_SHORT_LEN = len(COORD_KEYS_SHORT)-1
+COORD_KEY_SHORT_LEN = len(COORD_KEYS_SHORT)
 
 COORD_KEYS_MED = ('lon', 'lat', 'alt', 'roll', 'pitch', 'yaw')
-COORD_KEYS_MED_LEN = len(COORD_KEYS_MED) -1
+COORD_KEYS_MED_LEN = len(COORD_KEYS_MED)
 
 COORD_KEYS_X_SHORT = ('lon', 'lat', 'alt')
-COORD_KEYS_X_SHORT_LEN = len(COORD_KEYS_X_SHORT) - 1
+COORD_KEYS_X_SHORT_LEN = len(COORD_KEYS_X_SHORT)
 
 HOST = '147.135.8.169'  # Hoggit Gaw
 PORT = 42674
@@ -731,6 +731,7 @@ async def consumer(host: str,
             LOG.info(f'Starting shutdown due to: {err.__class__.__name__}')
             await copy_writer.cleanup()
             await sock.close(status='Success')
+
             total_time = time.time() - init_time
             LOG.info('Total Lines Processed : %s', str(lines_read))
             LOG.info('Total seconds running : %.2f', total_time)
